#! /bin/sh
#  ------------------------------------------------------------
#  Company: Software- und Organisations-Service GmbH
#  Purpose: Watchdog script for JobScheduler Agent
#  ------------------------------------------------------------


start_agent() 
{
  "${JAVABIN}" -DLOGFILE="${SCHEDULER_LOGFILE}" ${JAVA_OPTIONS} -classpath "${SCHEDULER_CLASSPATH}" com.sos.scheduler.engine.agent.main.AgentMain -http-port=${SCHEDULER_HTTP_PORT} -log-directory="${SCHEDULER_LOG_DIR}" -kill-script="${SCHEDULER_KILL_SCRIPT}" ${IP_ADDRESS_OPTION} -job-java-options="${JOB_JAVA_OPTIONS}" &
  SCHEDULER_EXIT=$?
  if [ "${SCHEDULER_EXIT}" = "0" ]
  then
	create_pid_file $!
	SCHEDULER_PID=$!
	echo "...JobScheduler Agent(${SCHEDULER_HTTP_PORT}) is started with pid=${SCHEDULER_PID}!"
	echo "...see log file ${SCHEDULER_LOGFILE}.log"
	echo "...watchdog for pid ${SCHEDULER_PID} is started"
	echo "Hit ENTER to return to your command prompt."
    wait "${SCHEDULER_PID}" 2>/dev/null
  fi 
}

create_pid_file() 
{
  SCHEDULER_PID=$1
  echo "${SCHEDULER_PID}" > "${SCHEDULER_PID_FILE}"
  if [ ! -f "${SCHEDULER_PID_FILE}" ]
  then
	echo "...pid file \"${SCHEDULER_PID_FILE}\" could not be created!"
    echo "...please check the permissions in \"${SCHEDULER_PID_FILE_DIR}\"."
    #kill -9 ${SCHEDULER_PID}
    exit 3
  else
    chmod 666 "${SCHEDULER_PID_FILE}" 2>/dev/null
  fi 
}

call_crash_file()
{
  date "+%Y-%m-%d %T,%3N %z [info]  Watchdog calls \"${SCHEDULER_CRASH_FILE}\"" >> "${SCHEDULER_LOGFILE}.log"
  if [ ! -s "${SCHEDULER_CRASH_FILE}" ]
  then
    date "+%Y-%m-%d %T,%3N %z [info]  \"${SCHEDULER_CRASH_FILE}\" doesn't exist or is empty. Nothing to do." >> "${SCHEDULER_LOGFILE}.log"
  else
    /bin/sh "${SCHEDULER_CRASH_FILE}"
  fi
}

start_agent
SCHEDULER_EXIT=$?
if [ "${SCHEDULER_EXIT}" != "0" ]
then
  date "+%Y-%m-%d %T,%3N %z [info]  JobScheduler Agent terminated abnormal" >> "${SCHEDULER_LOGFILE}.log"
  call_crash_file
fi

exit ${SCHEDULER_EXIT}